summaryrefslogtreecommitdiff
path: root/src/mongo/shell/shardingtest.js
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/shell/shardingtest.js')
-rw-r--r--src/mongo/shell/shardingtest.js12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mongo/shell/shardingtest.js b/src/mongo/shell/shardingtest.js
index 55c76c18bb8..ad286256004 100644
--- a/src/mongo/shell/shardingtest.js
+++ b/src/mongo/shell/shardingtest.js
@@ -18,7 +18,7 @@
* configuration object(s)(*). @see MongoRunner.runMongos
*
* mongosWaitsForKeys {boolean}: if true, wait for mongos to discover keys from the config
* server and to start sending logical times.
*
* rs {Object|Array.<Object>}: replica set configuration object. Can
* contain:
@@ -1487,19 +1487,19 @@ var ShardingTest = function(params) {
}
// Mongos does not block for keys from the config servers at startup, so it may not initially
// return logical times. If mongosWaitsForKeys is set, block until all mongos servers have found
// the keys and begun to send logical times. Retry every 500 milliseconds and timeout after 60
// seconds.
if (params.mongosWaitsForKeys) {
assert.soon(function() {
for (let i = 0; i < numMongos; i++) {
const res = self._mongos[i].adminCommand({isMaster: 1});
- if (!res.hasOwnProperty("$logicalTime")) {
- print("Waiting for mongos #" + i + " to start sending logical times.");
+ if (!res.hasOwnProperty("$clusterTime")) {
+ print("Waiting for mongos #" + i + " to start sending cluster times.");
return false;
}
}
return true;
- }, "waiting for all mongos servers to return logical times", 60 * 1000, 500);
+ }, "waiting for all mongos servers to return cluster times", 60 * 1000, 500);
}
};
@@ -18,7 +18,7 @@
*
* mongosWaitsForKeys {boolean}: if true, wait for mongos to discover keys from the config
- * server and to start sending logical times.
+ * server and to start sending cluster times.
*
* rs {Object|Array.<Object>}: replica set configuration object. Can
@@ -1487,19 +1487,19 @@ var ShardingTest = function(params) {
}
// Mongos does not block for keys from the config servers at startup, so it may not initially
- // return logical times. If mongosWaitsForKeys is set, block until all mongos servers have found
- // the keys and begun to send logical times. Retry every 500 milliseconds and timeout after 60
+ // return cluster times. If mongosWaitsForKeys is set, block until all mongos servers have found
+ // the keys and begun to send cluster times. Retry every 500 milliseconds and timeout after 60
// seconds.
if (params.mongosWaitsForKeys) {